@@ -1,5 +1,5 @@
 package Bio::Roary::PostAnalysis;
-$Bio::Roary::PostAnalysis::VERSION = '3.1.2';
+$Bio::Roary::PostAnalysis::VERSION = '3.1.3';
 # ABSTRACT: Post analysis of pan genomes
 
 
@@ -250,7 +250,7 @@ sub _build__groups_multifastas_nuc_obj
       group_names     => $self->_analyse_groups_obj->_groups,
       group_limit     => $self->group_limit,
 	  core_definition => $self->core_definition,
-	  dont_delete     => $self->dont_delete_files
+	  dont_delete_files => $self->dont_delete_files
     );
 }
 
@@ -320,7 +320,7 @@ Bio::Roary::PostAnalysis - Post analysis of pan genomes
 
 =head1 VERSION
 
-version 3.1.2
+version 3.1.3
 
 =head1 SYNOPSIS
 
